@@ -93,7 +93,7 @@ class Mojitos:
             self.cmdline += ' -r'
         if self.load:
             self.cmdline += ' -u'
-        self.cmdline += ' -o /dev/shm/monitoring &'
+        self.cmdline += ' -o /dev/shm/monitoring_moj &'
 
 
     def start(self):
@@ -110,8 +110,8 @@ class Mojitos:
         os.makedirs(filename_moj, exist_ok=True)
         if len(self.executor.hostnames) > 1:
             for hostname in self.executor.hostnames:
-                self.executor.local('oarcp %s:/dev/shm/monitoring %s/%s_%s_%s' %
+                self.executor.local('oarcp %s:/dev/shm/monitoring_moj %s/%s_%s_%s' %
                                     (hostname, filename_moj, hostname, benchname, beg_time))
         else:
-            self.executor.local('cp /dev/shm/monitoring %s/%s_%s_%s' %
+            self.executor.local('cp /dev/shm/monitoring_moj %s/%s_%s_%s' %
                                     (filename_moj, 'localhost', benchname, beg_time))
